@@ -1,7 +1,10 @@
-rxPermissive({
-
+rxodeTest(
+  {
     context("Issue #178: deactivate active compiled model")
-    test_that("178", {
+    td <- tempdir()
+
+    .rxWithWd(td, {
+      test_that("178", {
         ## Define model
         skip_on_os("solaris")
         skip_on_os("mac")
@@ -14,21 +17,21 @@ rxPermissive({
    d/dt(eff) = Kin*(1-C2/(EC50+C2)) - Kout*eff;
 "
 
-    mod1 <- RxODE(model = ode, modName = "mod1")
+        mod1 <- RxODE(model = ode, modName = "mod1")
 
-    ode <- "
+        ode <- "
    C2 = centr/V2;
    d/dt(depot) = -KA*depot;
    d/dt(centr) = KA*depot - CL*C2;
    d/dt(eff) = Kin*(1-C2/(EC50+C2)) - Kout*eff;
 "
 
-    ## Compile model
-    mod1 <- RxODE(model = ode, modName = "mod1")
+        ## Compile model
+        mod1 <- RxODE(model = ode, modName = "mod1")
 
-    expect_equal(rxModelVars(ode)$params, rxModelVars(mod1)$params)
-})
-
-
-
-}, cran=FALSE)
+        expect_equal(rxModelVars(ode)$params, rxModelVars(mod1)$params)
+      })
+    })
+  },
+  test = "lvl2"
+)
